@@ -72,23 +72,31 @@ def build_input_para():
     print('#     2. Spatial axis binning: 1 pixel')
     print('#     3. Gain: 1 e-/ADU')
     print('#     4. Dark: 0.017 e-/s/pixel')
+    print('#     5. readout_noise: 5.5 e-/pixel')
 
     readout_xbin = 1
     readout_ybin = 1
     gain = 1
     dark = 0.017
+    readout_noise = 5.5
 
     tmp1 = False
     while tmp1 is False:
 
-        flag_change = input('Reset the parameters or use the default value? (r|d): ')
+        print('# Whether or not change the default paramters: ')
+        print('#    1. Reset the parameters.')
+        print('#    2. Use the default paramters.')
+        flag_change = check_input(input_message='Enter the index: ',
+                                  input_type=int,
+                                  input_range=(1, 2),
+                                  input_default='2')
 
-        if flag_change == 'r':
+        if flag_change == 1:
 
             tmp2 = False
             while tmp2 is False:
 
-                flag_number = input('The parameter index you want to change (1-4): ')
+                flag_number = input('The parameter index you want to change (1-5): ')
                 if flag_number == '1':
                     readout_xbin = check_input(input_message='Dispersion axis binning',
                                 input_type=int,
@@ -140,8 +148,23 @@ def build_input_para():
                         print('The input needs to be (y|n). Retry.')
                         tmp2 = False
 
+                elif flag_number == '5':
+                    readout_noise = check_input(input_message='Readout Noise',
+                                       input_type=float,
+                                       input_range=(2, 7),
+                                       input_default=5.5)
+
+                    flag_next = input('whether or not change another one ? (y|n): ')
+                    if flag_next == 'n':
+                        tmp2 = True
+                    elif flag_next == 'y':
+                        tmp2 = False
+                    else:
+                        print('The input needs to be (y|n). Retry.')
+                        tmp2 = False
+
                 else:
-                    print('The input needs to be (1-4). Retry.')
+                    print('The input needs to be (1-5). Retry.')
                     tmp2 = False
 
             tmp1 = True
@@ -151,34 +174,30 @@ def build_input_para():
             print('#     2. Spatial axis binning: ' + str(readout_ybin) + ' pixel')
             print('#     3. Gain: ' + str('{:3.1f}'.format(gain)) + ' e-/ADU')
             print('#     4. Dark: ' + str('{:4.3f}'.format(dark)) + ' e-/s/pixel')
+            print('#     5. Readout noise: ' + str('{:4.3f}'.format(readout_noise)) + ' e-/pixel')
 
-        elif flag_change == 'd':
+        elif flag_change == 2:
 
             print('# Use the default CCD parameters. ')
             tmp1 = True
 
-        else:
-            print('The input needs to be (r|d). Retry.')
-            tmp1 = False
-
     calc['configuration'] = get_instrument_config(readout_xbin=readout_xbin,
                                                   readout_ybin=readout_ybin,
                                                   gain=gain,
                                                   dark=dark)
 
-
     # calculation modes.
     obst = 300.
     print('#')
     print('# 3. Specify the calculation mode: ')
-    print('#     1. How many visits needed to obtain a certain SNR.')
+    print('#     1. How many visits needed to obtain a certain SNR [under development, useless.].')
     print('#     2. SNR reached in certain visits.')
     print('#     (Set the exposure time = 300 seconds per visit.)')
 
     calc_mode = check_input(input_message='which calculation mode',
                              input_type=int,
                              input_range=(1, 2),
-                             input_default=1)
+                             input_default=2)
 
     if calc_mode == 1:
 
@@ -207,12 +226,12 @@ def build_input_para():
 
     print('#')
     print('# 4. Specify the source: ')
-    print('#     1. import a simulated datacube.')
+    print('#     1. import a simulated datacube. [under development.] ')
     print('#     2. Define the source (position, shape, spectrum, brightness).')
     source_mode = check_input(input_message='Select one way',
                             input_type=int,
                             input_range=(1, 2),
-                            input_default=1)
+                            input_default=2)
 
     # import the simulated datacube.
     if source_mode == 1:
@@ -250,7 +269,7 @@ def build_input_para():
             isource_type = check_input(input_message='Enter the index',
                              input_type=int,
                              input_range=(1, 2),
-                             input_default=1)
+                             input_default=2)
 
             # set the central xy-offset
             print('# 4. (2/5) Set the center position for source-' + str(i+1) + ': ')
